@@ -17,8 +17,9 @@
 # under the License.
 from __future__ import annotations
 
+from collections.abc import Sequence
 from datetime import timedelta
-from typing import TYPE_CHECKING, Any, Callable, Sequence
+from typing import TYPE_CHECKING, Any, Callable
 
 from airflow.configuration import conf
 from airflow.exceptions import AirflowException
@@ -48,7 +49,7 @@ class HttpSensor(BaseSensorOperator):
 
         def response_check(response, task_instance):
             # The task_instance is injected, so you can pull data form xcom
-            # Other context variables such as dag, ds, execution_date are also available.
+            # Other context variables such as dag, ds, logical_date are also available.
             xcom_data = task_instance.xcom_pull(task_ids="pushing_task")
             # In practice you would do something more sensible with this data..
             print(xcom_data)
